Learn R Programming

MultiSkew (version 1.1.1)

FisherSkew: Fisher's measure of skewness

Description

Computes Fisher's measure of skewness, that is the third standardized moment of each variable in the dataset

Usage

FisherSkew(data)

Arguments

data

data matrix

Value

Dataframe containing Fisher's measure of skewness of each variable of the dataset

Examples

Run this code
data(PM10_2006)
PM10_2006_matrix<-data.matrix(PM10_2006)
FisherSkew(PM10_2006_matrix)

Run the code above in your browser using DataLab