Learn R Programming

MultiSkew (version 1.1.1)

PartialSkew: PartialSkew

Description

Multivariate skewness, as defined in Mori, Rohatgi e Szekely (1993).

Usage

PartialSkew(data)

Arguments

data

data matrix

Value

Vector

The vector-valued skewness introduced by Mori et al (1993)

Scalar

The squared norm of Vector

pvalue

The probability of observing a value of Scalar greater than the observed one, when data are normally distributed

%% ...

References

Mori T.F., Rohatgi V.K. and Szekely G.J. (1993). On multivariate skewness and kurtosis. Theory Probab. Appl. 38, 547-551.

Examples

Run this code
data(PM10_2006)
PM10_2006_matrix<-data.matrix(PM10_2006)
PartialSkew(PM10_2006_matrix[,2:5])

Run the code above in your browser using DataLab