Learn R Programming

MultiSkew (version 1.1.1)

SkewMardia: Multivariate skewness as defined in Mardia (1970)

Description

Sum of squared elements in the third standardized cumulant of the data matrix.

Usage

SkewMardia(data)

Arguments

data

data matrix

Value

MardiaSkewness

Squared norm of the third cumulant of the standardized data

pvalue

Probability of observing a value of MardiaSkewness greater than the observed one, when data are normally distributed.

%% ...

References

Mardia, K.V. (1970), Measures of multivariate skewness and kurtosis with applications.Biometrika 57, 519-530.

Examples

Run this code
data(PM10_2006)
PM10_2006_matrix<-data.matrix(PM10_2006)
SkewMardia(PM10_2006_matrix[,2:5])

Run the code above in your browser using DataLab