powered by
Computes Fisher's measure of skewness, that is the third standardized moment of each variable in the dataset
FisherSkew(data)
data matrix
Dataframe containing Fisher's measure of skewness of each variable of the dataset
data(PM10_2006) PM10_2006_matrix<-data.matrix(PM10_2006) FisherSkew(PM10_2006_matrix)
Run the code above in your browser using DataLab