powered by
Sum of squared elements in the third standardized cumulant of the data matrix.
SkewMardia(data)
data matrix
Squared norm of the third cumulant of the standardized data
Probability of observing a value of MardiaSkewness greater than the observed one, when data are normally distributed.
Mardia, K.V. (1970), Measures of multivariate skewness and kurtosis with applications.Biometrika 57, 519-530.
data(PM10_2006) PM10_2006_matrix<-data.matrix(PM10_2006) SkewMardia(PM10_2006_matrix[,2:5])
Run the code above in your browser using DataLab